package org.example;

import static org.junit.Assert.*;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.Statement;
import java.sql.Types;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/***
 * <p>A brief test case to illustrate problems with JDBC type mapping to MySQL TEXT columns</p>
 * <p>This will start the embedded server on the machine but not properly close it. You may need 
 * to kill the mysql process and then remove the mysql-c.mxj directory from %TEMP%. 
 * Also if you're testing with Win7-64 bit you need to adjust the platform-map.properties file
 * and add the following line:
 * <pre>Windows_7-amd64=Win-x86</pre>
 * otherwise the mysql binaries won't be found.
 */
public class TestTextTypeBug {

  Connection conn;
  
  @Before
  public void setUp() throws Exception {
    Class.forName("com.mysql.jdbc.Driver");
    conn = DriverManager.getConnection("jdbc:mysql:mxj:///test", null);
  }
  
  @After
  public void tearDown() throws Exception {
    conn.close();
  }

  @Test
  public void test() throws SQLException {
    Statement stmt = conn.createStatement();
    stmt.executeUpdate("CREATE TABLE IF NOT EXISTS TESTTABLE(TESTCOL TEXT)");
    ResultSet rs = stmt.executeQuery("SELECT * FROM TESTTABLE");
    ResultSetMetaData metadata = rs.getMetaData();
    assertEquals("VARCHAR", metadata.getColumnTypeName(1));
    assertEquals(Types.VARCHAR, metadata.getColumnType(1));
  }

}
